@@ -31,8 +31,8 @@ from ._helpers import (
     get_payment_data,
     get_payment_event_data,
     get_split_data,
-    get_split_data_v2,
-    get_split_data_v2_complete,
+    get_split_data_complete,
+    get_split_data_invalid,
     get_update_data,
 )
 
@@ -128,22 +128,14 @@ class PaymentTestCase(TestCase):
 
     def test_encoders(self):
         payment = Payment(**get_payment_event_data())
-        validated_split = payment.payment.split
+        empty_split = payment.payment.split
 
         payment_empty_notify = Payment(**get_payment_event_data())
         payment_empty_notify.links.notify = None
 
-        payment_data_v2 = payment.payment
-        payment_data_v2.set_split(get_split_data_v2())
-        payment_v2 = Payment(**get_payment_event_data(payment=payment_data_v2))
-
-        payment_data_v2_complete = payment.payment
-        payment_data_v2_complete.set_split(get_split_data_v2_complete())
-        payment_v2_complete = Payment(**get_payment_event_data(payment=payment_data_v2_complete))
-
-        payment_data_v2_empty = payment.payment
-        payment_data_v2_empty.set_split(None)
-        payment_v2_empty_split = Payment(**get_payment_event_data(payment=payment_data_v2_empty))
+        payment_data_with_split = payment.payment
+        payment_data_with_split.split = get_split_data_complete()
+        payment_with_split = Payment(**get_payment_event_data(payment=payment_data_with_split))
 
         payment_data = PaymentData(**get_payment_data())
         split = PaymentDataSplit(**get_split_data())
@@ -155,32 +147,34 @@ class PaymentTestCase(TestCase):
         payer = Payer(**get_payer_data())
 
         self.assertEqual(json.loads(payment.json())['id'], 'bb7044e4-066c-4bf7-915e-87ee97270eae')
-        self.assertEqual(validated_split, [])
-        self.assertEqual(json.loads(payment_v2.json())['payment']['split'], {'c_1': 14.0, 'c_2': None})
+        self.assertEqual(empty_split, [])
         self.assertEqual(
-            json.loads(payment_v2_complete.json())['payment']['split'],
+            json.loads(payment_with_split.json())['payment']['split'],
             [
                 {
-                    'id': 'c_1',
-                    'tipo': 'Tipo c1',
-                    'codice': 'Codice c1',
-                    'descrizione': 'Descrizione c1',
-                    'importo': 16.0,
-                    'capitolo_bilancio': 'Capitolo di bilancio c1',
-                    'accertamento': 'Accertamento c1',
+                    'code': 'c_1',
+                    'amount': 16.0,
+                    'meta': {
+                        'split_type': 'Tipo c1',
+                        'split_code': 'Codice c1',
+                        'split_description': 'Descrizione c1',
+                        'split_budget_chapter': 'Capitolo di bilancio c1',
+                        'split_assessment': 'Accertamento c1',
+                    },
                 },
                 {
-                    'id': 'c_2',
-                    'tipo': 'Tipo c2',
-                    'codice': 'Codice c2',
-                    'descrizione': 'Descrizione c12',
-                    'importo': 0.5,
-                    'capitolo_bilancio': 'Capitolo di bilancio c2',
-                    'accertamento': 'Accertamento c2',
+                    'code': 'c_2',
+                    'amount': 0.5,
+                    'meta': {
+                        'split_type': 'Tipo c2',
+                        'split_code': 'Codice c2',
+                        'split_description': 'Descrizione c12',
+                        'split_budget_chapter': 'Capitolo di bilancio c2',
+                        'split_assessment': 'Accertamento c2',
+                    },
                 },
             ],
         )
-        self.assertEqual(json.loads(payment_v2_empty_split.json())['payment']['split'], None)
         self.assertEqual(json.loads(payment.json())['created_at'], '2022-06-08T08:28:42+00:00')
         self.assertEqual(json.loads(payment.status.json()), PaymentStatus.STATUS_CREATION_PENDING.value)
         self.assertEqual(json.loads(payment.type.json()), PaymentType.TYPE_PAGOPA.value)
@@ -202,10 +196,8 @@ class PaymentTestCase(TestCase):
         self.assertEqual(len(json.loads(links.json())['notify']), 1)
         self.assertEqual(json.loads(payer.json())['type'], PayerType.TYPE_HUMAN.value)
         with self.assertRaises(ValidationError):
-            PaymentData(
-                **get_payment_data(
-                    split='Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt '
-                    'ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco '
-                    'laboris nisi ut aliquip ex ea commodo consequat.',
-                ),
-            )
+            PaymentData(**get_payment_data(split=None))
+        with self.assertRaises(ValidationError):
+            PaymentData(**get_payment_data(split=get_split_data_invalid()))
+        with self.assertRaises(ValidationError):
+            PaymentData(**get_payment_data(split='Lorem ipsum'))
